# Use Cases
Overview of SAP LeanIX use cases.
As an enterprise architect, you steer the initiatives that shape the digital landscape of your organization. One of your initial tasks using SAP LeanIX is conducting an application portfolio assessment. This involves systematically reviewing and documenting your organization's applications, and assessing their interdependencies, usage, and business contribution. Beyond this foundational task, SAP LeanIX helps you with a range of use cases:
SAP LeanIX Application Portfolio Management | SAP LeanIX Technology Risk and Compliance | SAP LeanIX Architecture and Road Map Planning
---|---|---
[Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.") |  [Obsolescence Risk Management](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management?locale=en-US&state=PRODUCTION&version=CLOUD "Learn why obsolescence risk management matters, how to discover risks associated with obsolete technology, how to assess their business impact, and how to efficiently manage and address them with SAP LeanIX.") |  [Application Modernization](https://help.sap.com/docs/leanix/ea/application-modernization?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX offers a strategic approach to modernizing outdated application portfolios, helping organizations reduce technical debt and operational costs while enhancing agility and innovation. This guide is useful for understanding how to effectively plan and execute continuous transformation tailored to specific organizational needs.")
[Application Rationalization](https://help.sap.com/docs/leanix/ea/application-rationalization?locale=en-US&state=PRODUCTION&version=CLOUD "Application rationalization reduces costs, eliminates redundancies, and improves efficiency. Optimize your application landscape with this step-by-step approach.") |  |  [ERP Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation?locale=en-US&state=PRODUCTION&version=CLOUD "Step-by-step guide for ERP Transformation using SAP LeanIX.")
[AI Governance and Adoption](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to implement AI governance practices in SAP LeanIX.") |  |


Ensure a smooth start to your SAP LeanIX initiatives by familiarizing yourself with the [Meta Model](https://help.sap.com/docs/leanix/ea/meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of the SAP LeanIX meta model and its key concepts.") and modeling guidelines before starting with your first use case. SAP LeanIX meta model, represented by fact sheet types and their relations, is at the heart of SAP LeanIX. It defines relationships between different fact sheet types, illustrating how information in fact sheets is interconnected. This blueprint assists you in understanding connections between various architectural objects. It allows for customization to meet unique organizational requirements and define your architectural structure and relationships.
